/************************************************************************/
/*		aPCI-P31A Device Driver											*/
/*																		*/
/*			apc31a.h	-	Win32 interface definition					*/
/************************************************************************/

#if !defined( APCI31A_H )
#define	APCI31A_H

#ifdef	__cplusplus
extern	"C" {
#endif

/*==================*/
/*	Error Code		*/
/*==================*/
#define	APCI31A_SUCCESS					0	/* Successfully proccessed */
#define	APCI31A_ERR_SYSTEM				1	/* Call GetLastError() */
#define	APCI31A_ERR_NO_DEVICE			2	/* No card */
#define	APCI31A_ERR_IN_USE				3	/* Device is in use */
#define	APCI31A_ERR_INVALID_SLOT		4	/* Invalid slot number */
#define	APCI31A_ERR_RESOURCE			5	/* Resource exhaustion */
#define	APCI31A_ERR_INVALID_PORT		6	/* Invalid port */
#define	APCI31A_ERR_INVALID_ARGUMENT	7	/* Invalid argument */
#define	APCI31A_ERR_NO_CREATE			8	/* No created device */

/*==========================================*/
/*	aPCI-P31A card's relative port address	*/
/*==========================================*/
#define	APCI31A_PORT_1	0
#define	APCI31A_PORT_2	1
#define	APCI31A_PORT_3	2
#define	APCI31A_PORT_4	3

/*==================*/
/*	Miscellaneous	*/
/*==================*/
#define	APCI31A_MAX_SLOTS	16			/* Maximum number of slots */
#define APCI31A_MAX_PORTS	4			/* Maximum number of user ports */

										/* default search */
#define	APCI31A_SLOT_AUTO		( ( WORD ) ~0U )

/*==============*/
/*	Device ID	*/
/*==============*/
#define	APCI31A_BOARD_ID	0x9131		/* pci bus device id */
#define	APCI31A_VENDOR_ID	0x136c		/* pci bus vendor id */
										/* our device id */
#define	APCI31A_DEVICE_ID	( ( DWORD )APCI31A_BOARD_ID\
							| ( ( DWORD )APCI31A_VENDOR_ID << 16 ) )

/*==================================*/
/*	Resource infomation structure	*/
/*==================================*/
#define	APCI31A_MAX_MEM		9			/* number of memory windows */
#define	APCI31A_MAX_IO		20			/* number of i/o windows */
#define	APCI31A_MAX_IRQ		7			/* number of irqs */
#define	APCI31A_MAX_DMA		7			/* number of dmas */

typedef	struct	_APCI31ARESOURCE {
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[APCI31A_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[APCI31A_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[APCI31A_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[APCI31A_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[APCI31A_MAX_IO];	/* I/O port length */
	DWORD	dwNumIRQs;							/* Not used */
	DWORD	dwIRQRegisters	[APCI31A_MAX_IRQ];	/* Not used */
	DWORD	dwIRQAttrib		[APCI31A_MAX_IRQ];	/* Not used */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[APCI31A_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[APCI31A_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} APCI31ARESOURCE, *PAPCI31AR;

#if !defined( APCI31A_DRIVER )
#define	APCI31A_API

#if !defined( APCI31A_DLL )
	#define APCI31ALIB_API	extern __declspec( dllimport )
#else
	#define APCI31ALIB_API	extern __declspec( dllexport )
#endif

#ifdef _BORLANDC_
	#define EXPVAR			__pascal
#else
	#define	EXPVAR
#endif

/*==================*/
/*	API Functions	*/
/*==================*/

APCI31ALIB_API BOOL	WINAPI	Apci31aGetVersion( PDWORD pdwDllVersion, PDWORD pdwDriverVersion );
APCI31ALIB_API BOOL	WINAPI	Apci31aCreate( PWORD pwLogSlot );
APCI31ALIB_API BOOL	WINAPI	Apci31aClose( WORD wLogSlot );
APCI31ALIB_API BOOL	WINAPI	Apci31aGetResource( WORD wLogSlot, PAPCI31AR pres );
APCI31ALIB_API BOOL	WINAPI	Apci31aGetSwitchValue( WORD wLogSlot, PDWORD pdwSwitchValue );
APCI31ALIB_API BOOL	WINAPI	Apci31aInPort( WORD wLogSlot, DWORD dwLogPort, PBYTE pbInValue );
APCI31ALIB_API BOOL	WINAPI	Apci31aOutPort( WORD wLogSlot, DWORD dwLogPort, BYTE bOutValue );
APCI31ALIB_API DWORD	WINAPI	Apci31aGetLastError( WORD wLogSlot );

#endif	/* #if !defined( APCI31A_DRIVER ) */

#ifdef	__cplusplus
}
#endif

#endif	/* #if !defined( APCI31A_H ) */

/**/